# hammer_sh Python Package

[![Version](https://img.shields.io/pypi/v/hammer_sh.svg)](https://pypi.python.org/pypi/hammer_sh) 
[![Support Python versions](https://img.shields.io/pypi/pyversions/hammer_sh.svg)](https://pypi.python.org/pypi/hammer_sh)

This is a package with useful classes and methods, that i used in my masterthesis.
